@@ -82,6 +82,10 @@ class Chart(xmlwriter.XMLwriter):
         self.hi_low_lines = None
         self.up_down_bars = None
         self.smooth_allowed = False
+        self.title_font = None
+        self.title_name = None
+        self.title_formula = None
+        self.title_data_id = None
 
         self._set_default_properties()
 
@@ -603,7 +607,7 @@ class Chart(xmlwriter.XMLwriter):
                 pass
             else:
                 # Otherwise use the default value.
-                axis['position_axis']
+                axis['position_axis'] = None
 
         # Set the font properties if present.
         axis['num_font'] = self._convert_font_args(options.get('num_font'))
@@ -634,7 +638,7 @@ class Chart(xmlwriter.XMLwriter):
             font['size'] *= 100
 
         # Convert rotation into 60,000ths of a degree.
-        if (font['rotation']):
+        if font['rotation']:
             font['rotation'] = 60000 * int(font['rotation'])
 
         return font
@@ -676,7 +680,7 @@ class Chart(xmlwriter.XMLwriter):
             return 'none'
 
         # Determine if data is numeric or strings.
-        for token in (data):
+        for token in data:
             if token is None:
                 continue
 
@@ -884,6 +888,7 @@ class Chart(xmlwriter.XMLwriter):
             'percentage': 'percentage',
             'standard_deviation': 'stdDev',
             'standard_error': 'stdErr',
+            'custom': 'cust',
         }
 
         # Check the error bars type.
@@ -913,6 +918,16 @@ class Chart(xmlwriter.XMLwriter):
                 # Default to 'both'.
                 pass
 
+        # Set any custom values.
+        if 'plus_values'in options:
+            error_bars['plus_values'] = options['plus_values']
+        if 'minus_values'in options:
+            error_bars['minus_values'] = options['minus_values']
+        if 'plus_data'in options:
+            error_bars['plus_data'] = options['plus_data']
+        if 'minus_data'in options:
+            error_bars['minus_data'] = options['minus_data']
+
         # Set the line properties for the error bars.
         error_bars['line'] = self._get_line_properties(options.get('line'))
         error_bars['fill'] = self._get_line_properties(options.get('fill'))
@@ -924,7 +939,7 @@ class Chart(xmlwriter.XMLwriter):
         gridline = {}
 
         # Set the visible property for the gridline.
-        gridline['visible'] = options.get('visible')
+        gridline = {'visible': options.get('visible')}
 
         # Set the line properties for the gridline.
         gridline['line'] = self._get_line_properties(options.get('line'))
@@ -989,7 +1004,7 @@ class Chart(xmlwriter.XMLwriter):
         if not user_points:
             return
 
-        for user_point in (user_points):
+        for user_point in user_points:
             point = {}
 
             if user_point is not None:
@@ -1015,7 +1030,7 @@ class Chart(xmlwriter.XMLwriter):
         # Returns series which use the primary axes.
         primary_axes_series = []
 
-        for series in (self.series):
+        for series in self.series:
             if not series['y2_axis']:
                 primary_axes_series.append(series)
 
@@ -1025,7 +1040,7 @@ class Chart(xmlwriter.XMLwriter):
         # Returns series which use the secondary axes.
         secondary_axes_series = []
 
-        for series in (self.series):
+        for series in self.series:
             if series['y2_axis']:
                 secondary_axes_series.append(series)
 
@@ -2113,7 +2128,7 @@ class Chart(xmlwriter.XMLwriter):
         self._write_legend_pos(position)
 
         # Remove series labels from the legend.
-        for index in (delete_series):
+        for index in delete_series:
             # Write the c:legendEntry element.
             self._write_legend_entry(index)
 
@@ -2825,7 +2840,7 @@ class Chart(xmlwriter.XMLwriter):
         if not points:
             return
 
-        for point in (points):
+        for point in points:
             index += 1
             if not point:
                 continue
@@ -3046,12 +3061,16 @@ class Chart(xmlwriter.XMLwriter):
         self._write_err_val_type(error_bars['type'])
 
         if not error_bars['endcap']:
-
             # Write the c:noEndCap element.
             self._write_no_end_cap()
 
-        if error_bars['type'] != 'stdErr':
-
+        if error_bars['type'] == 'stdErr':
+            # Don't need to write a c:errValType tag.
+            pass
+        elif error_bars['type'] == 'cust':
+            # Write the custom error tags.
+            self._write_custom_error(error_bars)
+        else:
             # Write the c:val element.
             self._write_error_val(error_bars['value'])
 
@@ -3094,6 +3113,63 @@ class Chart(xmlwriter.XMLwriter):
 
         self._xml_empty_tag('c:val', attributes)
 
+    def _write_custom_error(self, error_bars):
+        # Write the custom error bars tags.
+
+        if error_bars['plus_values']:
+            # Write the c:plus element.
+            self._xml_start_tag('c:plus')
+
+            if isinstance(error_bars['plus_values'], list):
+                self._write_num_lit(error_bars['plus_values'])
+            else:
+                self._write_num_ref(error_bars['plus_values'],
+                                    error_bars['plus_data'],
+                                    'num')
+            self._xml_end_tag('c:plus')
+
+        if error_bars['minus_values']:
+            # Write the c:minus element.
+            self._xml_start_tag('c:minus')
+
+            if isinstance(error_bars['minus_values'], list):
+                self._write_num_lit(error_bars['minus_values'])
+            else:
+                self._write_num_ref(error_bars['minus_values'],
+                                    error_bars['minus_data'],
+                                    'num')
+            self._xml_end_tag('c:minus')
+
+    def _write_num_lit(self, data):
+        # Write the <c:numLit> element for literal number list elements.
+        count = len(data)
+
+        # Write the c:numLit element.
+        self._xml_start_tag('c:numLit')
+
+        # Write the c:formatCode element.
+        self._write_format_code('General')
+
+        # Write the c:ptCount element.
+        self._write_pt_count(count)
+
+        for i in range(count):
+            token = data[i]
+
+            if token is None:
+                continue
+
+            try:
+                float(token)
+            except ValueError:
+                # Write non-numeric data as 0.
+                token = 0
+
+            # Write the c:pt element.
+            self._write_pt(i, token)
+
+        self._xml_end_tag('c:numLit')
+
     def _write_up_down_bars(self):
         # Write the <c:upDownBars> element.
         up_down_bars = self.up_down_bars
