@@ -49,7 +49,7 @@ class XMLwriter(object):
         # Write an XML start tag with optional attributes.
         for key, value in attributes:
             value = self._escape_attributes(value)
-            tag = tag + ' %s="%s"' % (key, value)
+            tag += ' %s="%s"' % (key, value)
 
         self.fh.write("<%s>" % tag)
 
@@ -58,7 +58,7 @@ class XMLwriter(object):
         # This is a minor speed optimisation for elements that don't
         # need encoding.
         for key, value in attributes:
-            tag = tag + ' %s="%s"' % (key, value)
+            tag += ' %s="%s"' % (key, value)
 
         self.fh.write("<%s>" % tag)
 
@@ -70,7 +70,7 @@ class XMLwriter(object):
         # Write an empty XML tag with optional attributes.
         for key, value in attributes:
             value = self._escape_attributes(value)
-            tag = tag + ' %s="%s"' % (key, value)
+            tag += ' %s="%s"' % (key, value)
 
         self.fh.write("<%s/>" % tag)
 
@@ -79,7 +79,7 @@ class XMLwriter(object):
         # This is a minor speed optimisation for elements that don't
         # need encoding.
         for key, value in attributes:
-            tag = tag + ' %s="%s"' % (key, value)
+            tag += ' %s="%s"' % (key, value)
 
         self.fh.write("<%s/>" % tag)
 
@@ -89,7 +89,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            tag = tag + ' %s="%s"' % (key, value)
+            tag += ' %s="%s"' % (key, value)
 
         data = self._escape_data(data)
         self.fh.write("<%s>%s</%s>" % (tag, data, end_tag))
@@ -100,7 +100,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            attr = attr + ' %s="%s"' % (key, value)
+            attr += ' %s="%s"' % (key, value)
 
         self.fh.write("""<c%s t="s"><v>%d</v></c>""" % (attr, index))
 
@@ -110,7 +110,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            attr = attr + ' %s="%s"' % (key, value)
+            attr += ' %s="%s"' % (key, value)
 
         string = self._escape_data(string)
 
@@ -127,7 +127,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            attr = attr + ' %s="%s"' % (key, value)
+            attr += ' %s="%s"' % (key, value)
 
         self.fh.write("""<c%s><v>%.15g</v></c>""" % (attr, number))
 
@@ -137,7 +137,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            attr = attr + ' %s="%s"' % (key, value)
+            attr += ' %s="%s"' % (key, value)
 
         self.fh.write("""<c%s><f>%s</f><v>%s</v></c>"""
                       % (attr, self._escape_data(formula),
@@ -154,7 +154,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            attr = attr + ' %s="%s"' % (key, value)
+            attr += ' %s="%s"' % (key, value)
 
         string = self._escape_data(string)
 
@@ -167,7 +167,7 @@ class XMLwriter(object):
 
         for key, value in attributes:
             value = self._escape_attributes(value)
-            attr = attr + ' %s="%s"' % (key, value)
+            attr += ' %s="%s"' % (key, value)
 
         self.fh.write("""<c%s t="inlineStr"><is>%s</is></c>""" %
                       (attr, string))
